#!/bin/sh
# script to download latest version from github
# author: [gghibo]

release=2022.12
gitname=git-tools
url=https://github.com/MestreLion/git-tools

if [ -d "$(pwd)/${gitname}" ]; then
	pushd ${gitname}
	git pull
	popd
else
	git clone ${url}
fi

pushd ${gitname}
	# abbreviated githash
	githash=$(git log -n 1 --pretty='format:%h')

	# git last commit date
	gitdate=$(git log -n 1 --pretty='format:%cd' --date=format:'%Y-%m-%d %H:%M:%S')

	# choosen suffix like in git-tools-2019.11-20200417.git.1115218.tar.xz
	gitsuffix=$(git log -n 1 --pretty='format:%cd.%h' --date=format:'%Y%m%d.git')

	# extract archive but don't change internal prefix
	release=$(git describe --tags --abbrev=0 | sed -e 's@^v@@g')
	git archive --prefix="${gitname}-${release}/" HEAD > ../${gitname}-${release}-${gitsuffix}.tar
popd

# compress at best xz level
xz -v -T0 -9e -f ${gitname}-${release}-${gitsuffix}.tar
